@@ -12,7 +12,7 @@ def add_lib_to_dll_path(path):
     except (AttributeError,KeyError,FileNotFoundError):
         pass
 
-if 'ON' == 'ON':
+if 'OFF' == 'ON':
     add_lib_to_dll_path('/usr/lib/libcudnn.so')
     add_lib_to_dll_path('/opt/cuda/lib64/libcudart.so')
 
